ButtonFormField class

Inheritance

Constructors

ButtonFormField({required String? buttonLabel})
ButtonFormField.fromMap(dynamic map)
factory

Properties

alternativeFieldName → String?
no setterinherited
annotations → List?
no setterinherited
buttonLabel → String?
final
fullyQualifiedName → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isDirty → bool?
no setterinherited
isNoExport → bool?
no setterinherited
isReadOnly → bool?
no setterinherited
isRequired → bool?
no setterinherited
name → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PdfFormFieldTypes
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
populateCommonFields(dynamic map) → void
inherited
populateWebCommonFields(dynamic map) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited