DocumentSaveOptions class

Options for saving/exporting a document.

Constructors

DocumentSaveOptions({String? userPassword, String? ownerPassword, bool? flatten, bool? incremental, List<DocumentPermissions>? permissions, PdfVersion? pdfVersion, bool? excludeAnnotations, bool? saveForPrinting, bool? includeComments, dynamic outputFormat, bool? optimize})

Properties

excludeAnnotations → bool?
Whether to exclude annotations from the exported document.
final
flatten → bool?
Flatten annotations and form fields into the page content.
final
hashCode → int
The hash code for this object.
no setterinherited
includeComments → bool?
// Whether to include comments in the exported document (Server-Backed only).
final
incremental → bool?
Whether to save the document incrementally.
final
optimize → bool?
Whether to optimize the document for the web.
final
outputFormat → dynamic
Whether tp allow you to export a PDF in PDF/A format.
final
ownerPassword → String?
The owner password is used to encrypt the document and set permissions. It's only used on Web.
final
pdfVersion → PdfVersion?
The PDF version to save the document as.
final
permissions → List<DocumentPermissions>?
The permissions to set on the document. See DocumentPermissions for more information.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveForPrinting → bool?
Whether to exclude annotations that have the noPrint flag set to true from the exported document (Standalone only)
final
userPassword → String?
The password is used to encrypt the document. On Web, it's used as the user password.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the options to a map that can be passed to the platform channel.
toString() → String
A string representation of this object.
inherited
toWebOptions() → Map<String, dynamic>
Converts the options to a map that can be passed to the web function call.

Operators

operator ==(Object other) → bool
The equality operator.
inherited