MeasurementScale class

The scale of the document. The scale is used to convert between real world measurements and points. The default scale is 1 inch = 1 inch.

Constructors

MeasurementScale({required UnitFrom unitFrom, required double valueFrom, required UnitTo unitTo, required double valueTo})
Scale constructor for the measurement scale of the document. @param fromUnits The unit of the valueFrom. @param valueFrom The value of the fromUnits. @param toUnits The unit of the valueTo. @param valueTo The value of the toUnits. @return Scale object.
MeasurementScale.fromMap(Map<String, dynamic> map)
factory
MeasurementScale.fromWebMap(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unitFrom → UnitFrom
The unit to convert from.
final
unitTo → UnitTo
The unit to convert to.
final
valueFrom → double
The original scale.
final
valueTo → double
The final scale.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
@return The scale as a map.
toString() → String
A string representation of this object.
override
toWebMap() → Map

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

defaultScale() → MeasurementScale
The default scale is 1 inch = 1 cm.