MeasurementValueConfiguration class

Constructors

MeasurementValueConfiguration({required String? name, required MeasurementScale scale, required MeasurementPrecision precision, bool addToUndo = false, bool isSelected = false})
MeasurementValueConfiguration.fromMap(Map<String, dynamic> map)
factory
MeasurementValueConfiguration.fromWebMap(Map<String, dynamic> map)
factory

Properties

addToUndo → bool
Whether this configuration should be added to the undo stack.
final
hashCode → int
The hash code for this object.
no setterinherited
isSelected → bool
Whether this configuration is selected.
final
name → String?
final
precision → MeasurementPrecision
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → MeasurementScale
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
toWebMap() → Map<String, dynamic>

Operators

operator ==(Object other) → bool
The equality operator.
inherited