MissingPlatformDirectoryException class

An exception thrown when a directory that should always be available on the current platform cannot be obtained.

Implemented types

Constructors

MissingPlatformDirectoryException(String message, {Object? details})
Creates a new exception

Properties

details → Object?
Added details, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The explanation of the exception.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited