PdfFormField class abstract

Implementers

Constructors

PdfFormField()
PdfFormField.fromMap(dynamic map)
factory

Properties

alternativeFieldName → String?
no setter
annotations → List?
no setter
fullyQualifiedName → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDirty → bool?
no setter
isNoExport → bool?
no setter
isReadOnly → bool?
no setter
isRequired → bool?
no setter
name → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PdfFormFieldTypes
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
populateCommonFields(dynamic map) → void
populateWebCommonFields(dynamic map) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited