PspdfKitToolbarPlacement enum

An enum to represent the placement of the PSPDFKit toolbar.

The toolbar can be placed at the top or bottom of the screen.

Inheritance
Available extensions

Values

top → const PspdfKitToolbarPlacement
bottom → const PspdfKitToolbarPlacement

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webName → String?

Available on PspdfKitToolbarPlacement, provided by the WebToolbarPlacement extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PspdfKitToolbarPlacement>
A constant List of the values in this enum, in order of their declaration.