PspdfkitWebAnnotationToolbarItem class

Constructors

PspdfkitWebAnnotationToolbarItem({String? className, bool? disabled, String? icon, String? id, Function? onPress, String? title, required PspdfkitWebAnnotationToolbarItemType type})

Properties

className → String?
final
disabled → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
final
id → String?
final
onPress → Function?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final
type → PspdfkitWebAnnotationToolbarItemType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited