PspdfkitWebToolbarItem class

Represents a toolbar item in the PSPDFKit Web toolbar. See PSPDFKit.ToolbarItem

Constructors

PspdfkitWebToolbarItem({required PspdfkitWebToolbarItemType type, String? title, String? className, bool? disabled, String? dropdownGroup, String? icon, String? id, List<String>? mediaQueries, Function? onPress, String? preset, String? responsiveGroup, bool? selected})

Properties

className → String?
final
disabled → bool?
final
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
final
id → String?
final
mediaQueries → List<String>?
final
onPress → Function?
final
preset → String?
final
responsiveGroup → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool?
final
title → String?
final
type → PspdfkitWebToolbarItemType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited