ShapeAnnotationConfiguration class

Annotation configuration class for ShapeAnnotations annotation. Shape annotations include: Square, Circle, Polygon and Area Measurement.

Inheritance

Constructors

ShapeAnnotationConfiguration({Color? color, double thickness = 0.0, Color? fillColor, double? alpha, BorderStyle? borderStyle})

Properties

alpha → double?
final
blendMode ↔ BlendMode?
Available only on iOS
getter/setter pairinherited
borderStyle → BorderStyle?
final
color → Color?
final
fillColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
properties → Map<AnnotationConfigurationProperty, dynamic>?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProperty(AnnotationConfigurationProperty property, dynamic value) → void
Specify more annotation properties which can be used to configure annotation presets. These may not be available on all platforms. AnnotationConfigurationProperty is an enum which contains all the available properties. The value of the property can be of any type.
inherited
toMap() → Map<String, dynamic>
Returns a map of properties. This method is used internally by the SDK.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited